import Vue from 'vue'
import Vuex from 'vuex'
import { getUser, logout, getApp } from '@/api/base'

Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    appid: localStorage.getItem('appid') || '',
    app: {},
    eventTypes: [
      {
        name: '应用事件',
        tag: 'app',
        desc: '包含应用的修改事件',
        list: [{ name: '应用修改', tag: 'app.updated', desc: '在统一权限系统修改应用详情时触发事件通知' }]
      },
      {
        name: '用户事件',
        tag: 'user',
        desc: '包含用户的添加、停用、启用、角色变更事件',
        list: [
          { name: '用户添加(绑定)', tag: 'user.binded', desc: '在统一权限系统添加用户时触发事件通知' },
          { name: '用户停用', tag: 'user.stoped', desc: '在统一权限系统停用用户时触发事件通知' },
          { name: '用户启用', tag: 'user.enable', desc: '在统一权限系统启用用户时触发事件通知' },
          {
            name: '用户角色变更',
            tag: 'user.role.updated',
            desc: '在统一权限系统在角色管理中分配用户、删除角色时触发事件通知'
          }
        ]
      },
      {
        name: '角色事件',
        tag: 'role',
        desc: '包含角色的添加、删除、修改、权限变更事件',
        list: [
          { name: '角色添加', tag: 'role.created', desc: '在统一权限系统创建角色时触发事件通知' },
          { name: '角色修改', tag: 'role.updated', desc: '在统一权限系统修改权限时触发事件通知' },
          { name: '角色删除', tag: 'role.deleted', desc: '在统一权限系统删除角色时 触发事件通知' },
          {
            name: '权限变更通知',
            tag: 'role.permission.updated',
            desc: '在统一权限系统中分配权限、删除角色、添加权限、修改权限、删除权限时触发权限变更事件通知'
          }
        ]
      },
      {
        name: '权限事件',
        tag: 'permission',
        desc: '包含权限的添加、删除、修改、事件',
        list: [
          { name: '权限添加', tag: 'permission.created', desc: '在统一权限系统创建权限时触发事件通知' },
          { name: '权限修改', tag: 'permission.updated', desc: '在统一权限更新权限时触发事件通知' },
          { name: '权限删除', tag: 'permission.deleted', desc: '在统一权限系统删除权限时触发事件通知' }
        ]
      }
    ]
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setAppid(state, appid) {
      state.appid = appid
    },
    setApp(state, app) {
      state.app = app
    }
  },
  actions: {
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    async checkLogin({ commit }) {
      const isLogin = await getUser()
        .then(response => {
          if (response.code === 0) {
            commit('setUser', response.data)
            return true
          } else {
            commit('setUser', {})
            return false
          }
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      return isLogin
    },
    getApp({ commit, state }, appid) {
      appid = appid || state.appid
      appid &&
        getApp(appid).then(res => {
          commit('setApp', res.data)
        })
    }
  }
})
store.dispatch('getApp')
export default store
